==> nextcloud-23.0.12p0.tgz: nextcloud/lib/l10n/lb.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Keng Schreiwreschter op d' 'config' Verzeechnis!",
    "See %s" : "%s kucken",
    "Sample configuration detected" : "Beispill-Konfiguratioun erkannt",
    "PHP %s or higher is required." : "PHP %s oder méi nei ass néideg.",
    "PHP with a version lower than %s is required." : "PHP mat enger Versioun %s oder méi kleng ass néideg.",
    "Unknown filetype" : "Onbekannten Fichier Typ",
    "Invalid image" : "Ongülteg d'Bild",
    "today" : "haut",
    "yesterday" : "gëschter",
    "_%n day ago_::_%n days ago_" : ["%n Dag hier","%n Deeg hier"],
    "last month" : "Läschte Mount",
    "_%n month ago_::_%n months ago_" : ["%n Mount hier","%n Méint hier"],
    "last year" : "Läscht Joer",
    "_%n year ago_::_%n years ago_" : ["%n Joer hier","%n Joer hier"],
    "_%n hour ago_::_%n hours ago_" : ["%n Stonn hier","%n Stonnen hier"],
    "seconds ago" : "Sekonnen hir",
    "__language_name__" : "Lëtzebuergesch",
    "Help" : "Hëllef",
    "Apps" : "Applikatiounen",
    "Settings" : "Astellungen",
    "Log out" : "Ofmellen",
    "Users" : "Benotzer",
    "Email" : "Email",
    "Phone" : "Telefon",
    "Address" : "Adress",
    "About" : "Iwwer",
    "Set an admin password." : "Admin Passwuert setzen",
    "Sunday" : "Sonndeg",
    "Monday" : "Méindeg",
    "Tuesday" : "Dënschdeg",
    "Wednesday" : "Mëttwoch",
    "Thursday" : "Donneschdeg",
    "Friday" : "Freideg",
    "Saturday" : "Samschdeg",
    "Sun." : "So. ",
    "Mon." : "Méi.",
    "Tue." : "Dë.",
    "Wed." : "Më.",
    "Thu." : "Do.",
    "Fri." : "Fr.",
    "Sat." : "Sa.",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "Mäerz",
    "April" : "Abrëll",
    "May" : "Mee",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Dezember",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mäe.",
    "Apr." : "Abr.",
    "May." : "Mee",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dez.",
    "Authentication error" : "Authentifikatioun's Fehler",
    "Storage is temporarily not available" : "Späicherplaatz temporär net erreeschbar"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.11.tgz: nextcloud/lib/l10n/lb.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Keng Schreiwreschter op d' 'config' Verzeechnis!",
    "See %s" : "%s kucken",
    "Sample configuration detected" : "Beispill-Konfiguratioun erkannt",
    "PHP %s or higher is required." : "PHP %s oder méi nei ass néideg.",
    "PHP with a version lower than %s is required." : "PHP mat enger Versioun %s oder méi kleng ass néideg.",
    "Unknown filetype" : "Onbekannten Fichier Typ",
    "Invalid image" : "Ongülteg d'Bild",
    "Files" : "Fichieren",
    "today" : "haut",
    "yesterday" : "gëschter",
    "_%n day ago_::_%n days ago_" : ["%n Dag hier","%n Deeg hier"],
    "last month" : "Läschte Mount",
    "_%n month ago_::_%n months ago_" : ["%n Mount hier","%n Méint hier"],
    "last year" : "Läscht Joer",
    "_%n year ago_::_%n years ago_" : ["%n Joer hier","%n Joer hier"],
    "_%n hour ago_::_%n hours ago_" : ["%n Stonn hier","%n Stonnen hier"],
    "seconds ago" : "Sekonnen hir",
    "__language_name__" : "Lëtzebuergesch",
    "Apps" : "Applikatiounen",
    "Settings" : "Astellungen",
    "Log out" : "Ofmellen",
    "Email" : "Email",
    "Phone" : "Telefon",
    "Address" : "Adress",
    "About" : "Iwwer",
    "Set an admin password." : "Admin Passwuert setzen",
    "Sunday" : "Sonndeg",
    "Monday" : "Méindeg",
    "Tuesday" : "Dënschdeg",
    "Wednesday" : "Mëttwoch",
    "Thursday" : "Donneschdeg",
    "Friday" : "Freideg",
    "Saturday" : "Samschdeg",
    "Sun." : "So. ",
    "Mon." : "Méi.",
    "Tue." : "Dë.",
    "Wed." : "Më.",
    "Thu." : "Do.",
    "Fri." : "Fr.",
    "Sat." : "Sa.",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "Mäerz",
    "April" : "Abrëll",
    "May" : "Mee",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Dezember",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mäe.",
    "Apr." : "Abr.",
    "May." : "Mee",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dez.",
    "Authentication error" : "Authentifikatioun's Fehler",
    "Storage is temporarily not available" : "Späicherplaatz temporär net erreeschbar",
    "Help" : "Hëllef",
    "Users" : "Benotzer"
},
"nplurals=2; plural=(n != 1);");
